import { computed, unref, watchEffect } from "vue";
import throttle from "lodash/throttle";
const useThrottlePlugin = (fetchInstance, { throttleWait, throttleLeading, throttleTrailing }) => {
  const options = computed(() => {
    const ret = {};
    if (unref(throttleLeading) !== void 0) {
      ret.leading = unref(throttleLeading);
    }
    if (unref(throttleTrailing) !== void 0) {
      ret.trailing = unref(throttleTrailing);
    }
    return ret;
  });
  const throttledRef = computed(
    () => throttle(
      (callback) => {
        callback();
      },
      unref(throttleWait),
      options.value
    )
  );
  watchEffect((onInvalidate) => {
    if (unref(throttleWait)) {
      const _originRunAsync = fetchInstance.runAsync.bind(fetchInstance);
      fetchInstance.runAsync = (...args) => {
        return new Promise((resolve, reject) => {
          var _a;
          (_a = throttledRef.value) == null ? void 0 : _a.call(throttledRef, () => {
            _originRunAsync(...args).then(resolve).catch(reject);
          });
        });
      };
      onInvalidate(() => {
        var _a;
        fetchInstance.runAsync = _originRunAsync;
        (_a = throttledRef.value) == null ? void 0 : _a.cancel();
      });
    }
  });
  if (!unref(throttleWait)) {
    return {};
  }
  return {
    name: "throttlePlugin",
    onCancel: () => {
      var _a;
      (_a = throttledRef.value) == null ? void 0 : _a.cancel();
    }
  };
};
export {
  useThrottlePlugin as default
};
