import throttle from "lodash/throttle";
import { ref, computed, onUnmounted } from "vue";
function useThrottleFn(fn, options) {
  const fnRef = ref(fn);
  const wait = (options == null ? void 0 : options.wait) ?? 1e3;
  const throttled = computed(
    () => throttle(
      (...args) => {
        return fnRef.value([...args]);
      },
      wait,
      options
    )
  );
  onUnmounted(() => {
    throttled.value.cancel();
  });
  return {
    run: throttled,
    cancel: throttled.value.cancel,
    flush: throttled.value.flush
  };
}
export {
  useThrottleFn as default
};
