"use strict";
const vue = require("vue");
const useLocalStorageState = require("../useLocalStorageState");
const useMedia = require("../useMedia");
function useDarkMode() {
  const [enabledState, setEnabledState] = useLocalStorageState("dark-mode-enabled");
  const prefersDarkMode = usePrefersDarkMode();
  const enabled = vue.computed(() => {
    return typeof enabledState.value !== "undefined" ? enabledState.value : prefersDarkMode.value;
  });
  vue.watchEffect(() => {
    const className = "[vue-hooks-plus]-dark-mode";
    const element = window.document.body;
    if (enabled.value) {
      element.classList.add(className);
    } else {
      element.classList.remove(className);
    }
  });
  return [enabled, setEnabledState];
}
function usePrefersDarkMode() {
  return useMedia(["(prefers-color-scheme: dark)"], [true], false);
}
module.exports = useDarkMode;
