"use strict";
const debounce = require("lodash/debounce");
function useDebounceFn(fn, options) {
  const wait = (options == null ? void 0 : options.wait) ?? 1e3;
  const debounced = debounce(fn, wait, options);
  return {
    /**
     * Invode and pass parameters to fn.
     * `(...args: any[]) => any`
     */
    run: debounced,
    /**
     * Cancel the invocation of currently debounced function.
     *  `() => void`
     */
    cancel: debounced.cancel,
    /**
     * Immediately invoke currently debounced function.
     *  `() => void`
     */
    flush: debounced.flush
  };
}
module.exports = useDebounceFn;
