"use strict";
const vue = require("vue");
const utils = require("../devtools/utils");
const devToolsStore = require("../devtools/store");
const useDevtoolsPlugin = (fetchInstance, { ready = true, devKey, ...rest }) => {
  const createDevTarget = () => {
    if (devKey && !devToolsStore.has(devKey)) {
      const functionName = fetchInstance.serviceRef.value.toString().includes("function") ? utils.getFunctionName(fetchInstance.serviceRef.value.toString()) : utils.getArrowFunctionName(fetchInstance.serviceRef.value.toString());
      devToolsStore.insert(devKey, {
        instance: fetchInstance,
        requestName: functionName,
        time: Date.now()
      });
    }
  };
  vue.onMounted(() => {
    createDevTarget();
  });
  const processObj = vue.computed(
    () => Object.fromEntries(
      Object.entries({ ready, ...rest }).map(([key, value]) => [key, vue.unref(value)])
    )
  );
  vue.watchEffect(() => {
    if (devKey && devToolsStore.has(devKey)) {
      devToolsStore.emit({
        ...fetchInstance,
        options: { ...fetchInstance.options, ...processObj.value }
      });
    }
  });
  return {
    name: "devtoolsPlugin",
    onBefore: (params) => {
      createDevTarget();
      if (devKey && devToolsStore.has(devKey))
        devToolsStore.emit({
          ...fetchInstance.state,
          key: devKey,
          params,
          loading: true,
          time: Date.now(),
          type: "pending"
        });
    },
    onSuccess(data, params) {
      createDevTarget();
      if (devKey && devToolsStore.has(devKey))
        devToolsStore.emit({
          ...fetchInstance.state,
          key: devKey,
          data,
          params,
          loading: false,
          time: Date.now(),
          type: "done"
        });
    },
    onCancel() {
      createDevTarget();
      if (devKey && devToolsStore.has(devKey))
        devToolsStore.emit({
          ...fetchInstance.state,
          key: devKey,
          loading: false,
          time: Date.now(),
          type: "cancel"
        });
    },
    onError(e, params) {
      createDevTarget();
      if (devKey && devToolsStore.has(devKey))
        devToolsStore.emit({
          ...fetchInstance.state,
          key: devKey,
          params,
          loading: false,
          error: e,
          time: Date.now(),
          type: "error"
        });
    },
    onMutate(data) {
      createDevTarget();
      if (devKey && devToolsStore.has(devKey))
        devToolsStore.emit({
          ...fetchInstance.state,
          key: devKey,
          data,
          loading: false,
          time: Date.now(),
          type: "mutate"
        });
    }
  };
};
module.exports = useDevtoolsPlugin;
