"use strict";
const vue = require("vue");
const isDocumentVisible = require("../utils/isDocumentVisible");
const subscribeReVisible = require("../utils/subscribeReVisible");
const usePollingPlugin = (fetchInstance, { pollingInterval, pollingWhenHidden = true, pollingErrorRetryCount = -1 }) => {
  const timerRef = vue.ref();
  const unsubscribeRef = vue.ref();
  const countRef = vue.ref(0);
  const stopPolling = () => {
    var _a;
    if (timerRef.value) {
      clearInterval(timerRef.value);
    }
    (_a = unsubscribeRef.value) == null ? void 0 : _a.call(unsubscribeRef);
  };
  vue.watchEffect(() => {
    if (!vue.unref(pollingInterval)) {
      stopPolling();
    }
  });
  if (!vue.unref(pollingInterval)) {
    return {};
  }
  return {
    name: "pollingPlugin",
    onBefore: () => {
      stopPolling();
    },
    onError: () => {
      countRef.value += 1;
    },
    onSuccess: () => {
      countRef.value = 0;
    },
    onFinally: () => {
      if (pollingErrorRetryCount === -1 || // When an error occurs, the request is not repeated after pollingErrorRetryCount retries
      pollingErrorRetryCount !== -1 && countRef.value <= pollingErrorRetryCount) {
        timerRef.value = setTimeout(() => {
          if (!pollingWhenHidden && !isDocumentVisible()) {
            unsubscribeRef.value = subscribeReVisible(() => {
              fetchInstance.refresh();
            });
          } else {
            fetchInstance.refresh();
          }
        }, vue.unref(pollingInterval));
      } else {
        countRef.value = 0;
      }
    },
    onCancel: () => {
      stopPolling();
    }
  };
};
module.exports = usePollingPlugin;
