"use strict";
const throttle = require("lodash/throttle");
const vue = require("vue");
function useThrottleFn(fn, options) {
  const fnRef = vue.ref(fn);
  const wait = (options == null ? void 0 : options.wait) ?? 1e3;
  const throttled = vue.computed(
    () => throttle(
      (...args) => {
        return fnRef.value([...args]);
      },
      wait,
      options
    )
  );
  vue.onUnmounted(() => {
    throttled.value.cancel();
  });
  return {
    run: throttled,
    cancel: throttled.value.cancel,
    flush: throttled.value.flush
  };
}
module.exports = useThrottleFn;
